# -*- coding: utf-8 -*-
#
# File: testSetup.py
#
# Copyright (c) 2008 by Ecreall
# Generator: ArchGenXML Version 2.2 (svn)
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#

__author__ = """Vincent Fretin <vincentfretin@ecreall.com>"""
__docformat__ = 'plaintext'

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

##code-section module-header #fill in your manual code here
##/code-section module-header

#
# Setup tests
#

import os, sys
from Testing import ZopeTestCase
from Products.rendezvous.tests.testPlone import testPlone

class testSetup(testPlone):
    """Test cases for the generic setup of the product."""

    ##code-section class-header_testSetup #fill in your manual code here
    ##/code-section class-header_testSetup

    def afterSetUp(self):
        ids = self.portal.objectIds()

    def test_tools(self):
        ids = self.portal.objectIds()
        self.failUnless('archetype_tool' in ids)

    def test_types(self):
        ids = self.portal.portal_types.objectIds()
        self.failUnless('Document' in ids)

    def test_skins(self):
        ids = self.portal.portal_skins.objectIds()
        self.failUnless('plone_templates' in ids)

    def test_workflows(self):
        ids = self.portal.portal_workflow.objectIds()
        self.failUnless('plone_workflow' in ids)

    def test_workflowChains(self):
        getChain = self.portal.portal_workflow.getChainForPortalType
        self.failUnless(('plone_workflow' in getChain('Document')) or ('simple_publication_workflow' in getChain('Document')))

    # Manually created methods


def test_suite():
    from unittest import TestSuite, makeSuite
    suite = TestSuite()
    suite.addTest(makeSuite(testSetup))
    return suite

##code-section module-footer #fill in your manual code here
##/code-section module-footer

if __name__ == '__main__':
    framework()





# -*- coding: utf-8 -*-

from zope.interface import Interface

##code-section HEAD
##/code-section HEAD

class IRDV_RendezVous(Interface):
    """Marker interface for .RDV_RendezVous.RDV_RendezVous
    """

class IRDV_Proposition(Interface):
    """Marker interface for .RDV_Proposition.RDV_Proposition
    """

##code-section FOOT
##/code-section FOOT


# -*- coding: utf-8 -*-
#
# File: rendezvous.py
#
# Copyright (c) 2008 by Ecreall
# Generator: ArchGenXML Version 2.2 (svn)
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#

__author__ = """Vincent Fretin <vincentfretin@ecreall.com>"""
__docformat__ = 'plaintext'


# Product configuration.
#
# The contents of this module will be imported into __init__.py, the
# workflow configuration and every content type module.
#
# If you wish to perform custom configuration, you may put a file
# AppConfig.py in your product's root directory. The items in there
# will be included (by importing) in this file if found.

from Products.CMFCore.permissions import setDefaultRoles
##code-section config-head #fill in your manual code here
##/code-section config-head


PROJECTNAME = "rendezvous"

# Permissions
DEFAULT_ADD_CONTENT_PERMISSION = "Add portal content"
setDefaultRoles(DEFAULT_ADD_CONTENT_PERMISSION, ('Manager', 'Owner', 'Contributor'))
ADD_CONTENT_PERMISSIONS = {
    'RDV_RendezVous': 'rendezvous: Add RDV_RendezVous',
    'RDV_Proposition': 'rendezvous: Add RDV_Proposition',
}

setDefaultRoles('rendezvous: Add RDV_RendezVous', 'Manager, Owner, Reviewer, Editor')
setDefaultRoles('rendezvous: Add RDV_Proposition', 'Manager, Owner')

product_globals = globals()

# Dependencies of Products to be installed by quick-installer
# override in custom configuration
DEPENDENCIES = []

# Dependend products - not quick-installed - used in testcase
# override in custom configuration
PRODUCT_DEPENDENCIES = []

##code-section config-bottom #fill in your manual code here
##/code-section config-bottom


# Load custom configuration not managed by archgenxml
try:
    from Products.rendezvous.AppConfig import *
except ImportError:
    pass



# -*- coding: utf-8 -*-
#
# File: RDV_Proposition.py
#
# Copyright (c) 2008 by Ecreall
# Generator: ArchGenXML Version 2.2 (svn)
#            http://plone.org/products/archgenxml
#
# GNU General Public License (GPL)
#

__author__ = """Vincent Fretin <vincentfretin@ecreall.com>"""
__docformat__ = 'plaintext'

from AccessControl import ClassSecurityInfo
from Products.Archetypes.atapi import *
from zope.interface import implements
import interfaces

from Products.CMFDynamicViewFTI.browserdefault import BrowserDefaultMixin

from Products.rendezvous.config import *

##code-section module-header #fill in your manual code here
##/code-section module-header

copied_fields = {}
copied_fields['title'] = BaseSchema['title'].copy()
copied_fields['title'].required = 0
copied_fields['title'].write_permission = "rendezvous: write Proposition"
copied_fields['title'].widget.label = "A slot"
copied_fields['title'].widget.label_msgid = "rendezvous_Proposition_slot_label"
copied_fields['title'].widget.description = "A possible slot for this date"
copied_fields['title'].widget.description_msgid = "rendezvous_Proposition_slot_description"
copied_fields['title'].widget.i18n_domain = "rendezvous"
schema = Schema((

    copied_fields['title'],

    DateTimeField(
        name='date',
        widget=DateTimeField._properties['widget'](
            label="Date",
            label_msgid="rendezvous_Proposition_date_label",
            description="Possible date for the rendez-vous",
            description_msgid="rendezvous_Proposition_date_description",
            i18n_domain='rendezvous',
        ),
        required=1,
        write_permission="rendezvous: write Proposition",
    ),
    LinesField(
        name='available',
        widget=LinesField._properties['widget'](
            label="Members available",
            label_msgid="rendezvous_Proposition_available_label",
            description="List of participants who have checked this proposition",
            description_msgid="rendezvous_Proposition_available_description",
            visible=-1,
            i18n_domain='rendezvous',
        ),
    ),
    LinesField(
        name='unavailable',
        widget=LinesField._properties['widget'](
            label="Members unavailable",
            label_msgid="rendezvous_Proposition_unavailable_label",
            description="List of participants who haven't checked this proposition",
            description_msgid="rendezvous_Proposition_unavailable_description",
            visible=-1,
            i18n_domain='rendezvous',
        ),
    ),

),
)

##code-section after-local-schema #fill in your manual code here
##/code-section after-local-schema

RDV_Proposition_schema = BaseSchema.copy() + \
    schema.copy()

##code-section after-schema #fill in your manual code here
##/code-section after-schema

class RDV_Proposition(BaseContent, BrowserDefaultMixin):
    """
    """
    security = ClassSecurityInfo()

    implements(interfaces.IRDV_Proposition)

    meta_type = 'RDV_Proposition'
    _at_rename_after_creation = True

    schema = RDV_Proposition_schema

    ##code-section class-header #fill in your manual code here
    ##/code-section class-header

    # Methods

    security.declarePublic('manageParticipant')
    def manageParticipant(self, member_id, checked):
        """
        """
        available = list(self.getAvailable())
        unavailable = list(self.getUnavailable())
        if checked:
            if not member_id in available:
                available.append(member_id)
                self.setAvailable(available)
            if member_id in unavailable:
                unavailable.remove(member_id)
                self.setUnavailable(unavailable)
        else:
            if not member_id in unavailable:
                unavailable.append(member_id)
                self.setUnavailable(unavailable)
            if member_id in available:
                available.remove(member_id)
                self.setAvailable(available)


registerType(RDV_Proposition, PROJECTNAME)
# end of class RDV_Proposition

##code-section module-footer #fill in your manual code here
##/code-section module-footer



